ParameterTree — pyqtgraph 0.11.0rc0 documentation

# ParameterTree

class `pyqtgraph.parametertree.` `ParameterTree`(parent=None, showHeader=True)

  Widget used to display or control data from a hierarchy of Parameters

  `__init__`(parent=None, showHeader=True)

    Arguments: |
    parent | (QWidget) An optional parent widget
    showHeader | (bool) If True, then the QTreeView header is displayed.

  `addParameters`(param, root=None, depth=0, showTop=True)

    Adds one top-level `Parameter` to the view.

    Arguments: |
    param | The `Parameter` to add.
    root | The item within the tree to which param should be added. By default, param is added as a top-level item.
    showTop | If False, then param will be hidden, and only its children will be visible in the tree.

  `clear`()

    Remove all parameters from the tree.

  `contextMenuEvent`(self, arg__1: PySide2.QtGui.QContextMenuEvent)
  `focusNext`(item, forward=True)

    Give input focus to the next (or previous) item after item

  `selectionChanged`(self, selected: PySide2.QtCore.QItemSelection, deselected: PySide2.QtCore.QItemSelection)
  `setParameters`(param, showTop=True)

    Set the top-level `Parameter` to be displayed in this ParameterTree.

    If showTop is False, then the top-level parameter is hidden and only its children will be visible. This is a convenience method equivalent to:

        tree.clear()
        tree.addParameters(param, showTop)

  `wheelEvent`(self, arg__1: PySide2.QtGui.QWheelEvent)